#include <cstdio>
#include <cstring>
#include <queue>
#include <algorithm>

const int MAXN = 1000;
const int VERTEXS = MAXN*2+2;
const int INF = 0x3F3F3F3F;
struct Edge/*{{{*/
{
  int v, f, c;
  Edge *next, *op;
} g[(MAXN*2+MAXN*MAXN/2)*2], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int f, const int c, Edge* const op = 0)
{
  static int LinkSize = 0;
  Edge *node = g+(LinkSize++);
  node->v = y;
  node->f = f;
  node->c = c;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
inline void AddEdge(const int x, const int y, const int f, const int c)
{ add_edge(y, x, 0, -c, add_edge(x, y, f, c)); }/*}}}*/
struct AugRoad/*{{{*/
{
  int pre;
  Edge *e;
  void operator()(const int p, Edge* const x) { pre = p, e = x; }
} augroad[VERTEXS];
int S, T, nodes, dist[VERTEXS];
bool SPFA()
{
  static bool set[VERTEXS];
  static std::queue<int> Q;
  memset(dist, 0x3F, sizeof(dist));
  dist[S] = 0, set[S] = true;
  Q.push(S);
  for (int u; !Q.empty(); )
  {
    u = Q.front();
    Q.pop();
    set[u] = false;
    for (Edge *e = header[u]; e; e = e->next)
      if (e->f > 0 && dist[u] + e->c < dist[e->v])
      {
        dist[e->v] = dist[u] + e->c;
        augroad[e->v](u, e);
        if (!set[e->v])
        {
          set[e->v] = true;
          Q.push(e->v);
        }
      }
  }
  return dist[T] != INF;
}
int Costflow()
{
  int cost = 0;
  while (SPFA())
  {
    int minflow = INF;
    for (int u = T; u != S; u = augroad[u].pre)
      minflow = std::min(minflow, augroad[u].e->f);
    for (int u = T; u != S; u = augroad[u].pre)
    {
      augroad[u].e->f -= minflow;
      augroad[u].e->op->f += minflow;
      cost += minflow * augroad[u].e->c;
    }
  }
  return cost;
}/*}}}*/

int N, p, m, f, n, s;
int main()
{
  freopen("prog810.in", "r", stdin); 
  freopen("prog810.out", "w", stdout); 
  scanf("%d%d%d%d%d%d'", &N, &p, &m ,&f, &n, &s);
  S = 0, T = 2*N+1;
  for (int i = 1, x; i <= N; ++i)
  {
    scanf("%d", &x);
    AddEdge(S, i, x, 0);
    AddEdge(i+N, T, x, 0);
    AddEdge(S, i+N, INF, p);
    if (i+n <= N) AddEdge(i, i+N+n, INF, s);
    if (i+m <= N) AddEdge(i, i+N+m, INF, f);
    if (i+1 <= N) AddEdge(i, i+1, INF, 0);
  }
  printf("%d", Costflow());
  fclose(stdin);fclose(stdout); 
}
