#include <map>
#include <queue>
#include <cstdio>
#include <string>
#include <cstring>
#include <iostream>

const int INF = 0x3F3F3F3F;
const int MAXN = 100;
const int VERTEXS = MAXN*2+2;
struct Edge/*{{{*/
{
  int v, f, c;
  Edge *next, *op;
} g[(MAXN*MAXN+2+MAXN)*2], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int f, const int c, Edge* const op = 0)
{
  static int LinkSize = 0;
  Edge* node = g+(LinkSize++);
  node->v = y;
  node->f = f;
  node->c = c;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
inline void AddEdge(const int x, const int y, const int f, const int c)
{ add_edge(y, x, 0, -c, add_edge(x, y, f, c)); }/*}}}*/
struct AugRoad/*{{{*/
{
  int pre;
  Edge* e;
  void operator()(const int p, Edge* const x) { pre = p, e = x; }
} augroad[VERTEXS];
int S, T;
bool SPFA()
{
  static int dist[VERTEXS];
  static bool set[VERTEXS];
  static std::queue<int> Q;
  memset(dist, 0xC0, sizeof(*dist)*(T-S+1));
  dist[S] = 0, set[S] = true;
  Q.push(S);
  for (int u; !Q.empty(); Q.pop(), set[u] = false)
  {
    u = Q.front();
    for (Edge *e = header[u]; e; e = e->next)
      if (e->f > 0 && dist[u] + e->c > dist[e->v])
      {
        dist[e->v] = dist[u] + e->c;
        augroad[e->v](u, e);
        if (!set[e->v])
        {
          set[e->v] = true;
          Q.push(e->v);
        }
      }
  }
  return dist[T] != static_cast<int>(0xC0C0C0C0);
}
int Costflow()
{
  int cost = 0;
  while (SPFA())
  {
    int minflow = INF;
    for (int u = T; u != S; u = augroad[u].pre)
      minflow = std::min(minflow, augroad[u].e->f);
    for (int u = T; u != S; u = augroad[u].pre)
    {
      cost += minflow * augroad[u].e->c;
      augroad[u].e->f -= minflow;
      augroad[u].e->op->f += minflow;
    }
  }
  return cost;
}/*}}}*/
std::map<std::string, int> id;
std::vector<std::string> name;
int n, m;
std::vector<int> path[2];
void getsol(int u, std::vector<int>& path)
{
  path.push_back(1);
  while (u != n)
  {
    path.push_back(u);
    for (Edge *e = header[u+n]; e; e  = e->next)
      if (e->f == 0)
      {
        u = e->v;
        break;
      }
  }
}
int main()
{
  freopen("prog811.in", "r", stdin); 
  freopen("prog811.out", "w", stdout); 
  scanf("%d%d", &n, &m);
  name.reserve(n);
  S = 0, T = 2*n+1;
  AddEdge(S, 1, 2, 0);
  AddEdge(n+n, T, 2, 0);
  for (int i = 1; i <= n; ++i)
  {
    std::string s;
    std::cin >> s;
    name.push_back(s);
    id[s] = i;
    AddEdge(i, i+n, i != 1 && i != n ? 1 : 2, 1);
  }
  for (int i = 1; i <= m; ++i)
  {
    std::string sx, sy;
    std::cin >> sx >> sy;
    int x = id[sx], y = id[sy];
    if (x > y) 
      std::swap(x, y);
    AddEdge(x+n, y, 1, 0);
  }
  int costflow = Costflow();
  if (costflow == 0)
  {
    std::cout << "No Solution!";
    return 0;
  }
  std::cout << costflow-(header[S]->f == 0 ? 2 : 0) << std::endl;
  int p = 0;
  for (Edge *e = header[1+n]; e; e = e->next)
    if (e->f == 0)
      getsol(e->v, path[p++]);
  for (std::vector<int>::iterator iter = path[0].begin(); iter != path[0].end(); ++iter)
    std::cout << name[*iter-1] << std::endl;
  std::cout << name[n-1] << std::endl;
  if (header[S]->f == 0)
    for (std::vector<int>::reverse_iterator iter = path[1].rbegin(); iter != path[1].rend(); ++iter)
      std::cout << name[*iter-1] << std::endl;
  else
    std::cout << name[0];

  fclose(stdin);fclose(stdout); 
}
