#include <cstdio>
#include <cstring>
#include <algorithm>

const int MAXN = 15, MAXM = 20;
const int VERTEXS = MAXN*30+2;
const int INF = 0x3F3F3F3F;
struct Edge/*{{{*/
{
  int v, f;
  Edge *op, *next;
} g[(VERTEXS*MAXM)], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int w, Edge* const op = 0)
{
  static int LinkSize;
  Edge *node = g+(LinkSize++);
  node->v = y;
  node->f = w;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
inline void AddEdge(const int x, const int y, const int w)
{ add_edge(y, x, 0, add_edge(x, y, w));  }/*}}}*/
int day, n, m, K, maxflow, h[MAXM], s[MAXM][11];
int nodes, S, T, dist[VERTEXS], dc[VERTEXS];/*{{{*/
int SAP(const int u, const int delta)
{
  if (u == T)
    return delta;
  int sum = 0, mindist = nodes;
  for (Edge *e = header[u]; e; e = e->next)
  {
    if (dist[u]-1 == dist[e->v] && e->f > 0)
    {
      int d = SAP(e->v, std::min(delta-sum, e->f));
      e->f -= d;
      e->op->f += d;
      sum += d;
      if (dist[S] >= nodes || sum == delta)
        return sum;
    }
    if (e->f > 0)
      mindist = std::min(mindist, dist[e->v]);
  }
  if (sum == 0)
  {
    if (!--dc[dist[u]])
      dist[S] = nodes;
    else
      ++dc[dist[u] = mindist+1];
  }
  return sum;
}
int Maxflow()
{
  int maxflow = 0;
  memset(dc, 0, sizeof(dc));
  memset(dist, 0, sizeof(dist));
  dc[0] = nodes = n*day+2;
  while (dist[S] < nodes)
    maxflow += SAP(S, INF);
  return maxflow;
} /*}}}*/
bool Floyd()/*{{{*/
{
  static bool f[MAXN][MAXN];
  for (int i = 0; i < n; ++i)
    f[i][i] = true;
  for (int i = 0; i < m; ++i)
  {
    int count = s[i][0];
    for (int j = 1; j < count; ++j)
      f[s[i][j]][s[i][j+1]] = f[s[i][j+1]][s[i][j]] = true;
    f[s[i][1]][s[i][count]] = f[s[i][count]][s[i][1]] = true;
  }
  for (int k = 0; k < n; ++k)
    for (int i = 0; i < n; ++i)
      for (int j = 0; j < n; ++j)
        f[i][j] |= f[i][k] && f[k][j];
  return f[1][0];
}/*}}}*/
inline int Point(const int day, const int p) { return day*n+p; }
int main()
{
  freopen("prog813.in", "r", stdin); 
  freopen("prog813.out", "w", stdout); 

  S = VERTEXS-2, T = VERTEXS-1;
  scanf("%d%d%d", &n, &m, &K);
  for (int i = 0; i < m; ++i)
  {
    scanf("%d%d", h+i, &s[i][0]);
    for (int j = 1; j <= s[i][0]; ++j)
    {
      scanf("%d", &s[i][j]);
      s[i][j] += 1;
    }
  }
  n += 2;
  if (!Floyd())
  {
    printf("0");
    return 0;
  }

  int maxflow = 0;
  AddEdge(S, Point(day, 1), K);
  AddEdge(Point(day, 0), T, K);
  for (day = 1; true; ++day)
  {
    for (int i = 0; i < n; ++i)
      AddEdge(Point(day-1, i), Point(day, i), INF);
    for (int i = 0; i < m; ++i)
      AddEdge(Point(day-1, s[i][(day-1)%s[i][0]+1]), Point(day, s[i][day%s[i][0]+1]), h[i]);
    AddEdge(S, Point(day, 1), K);
    AddEdge(Point(day, 0), T, K);
    maxflow += Maxflow();
    if (maxflow >= K)
      break;
  }
  printf("%d", day);

  fclose(stdin);fclose(stdout); 
}
