#include <queue>
#include <cstdio>
#include <cstring>
#include <iostream>

const int INF = 0x3F3F3F3F;
const int MAXN = 20*20+20*19/2;
const int VERTEXS = MAXN*2+2;
int m, n, tot, mat[20][40], id[20][40];
struct Edge/*{{{*/
{
  int v, f, c;
  Edge *next, *op;
} g[(MAXN*2*2+MAXN+MAXN+20)*2], *header[VERTEXS];
int LinkSize = 0;
Edge* add_edge(const int x, const int y, const int f, const int c, Edge* const op = 0)
{
  Edge* node = g+(LinkSize++);
  node->v = y;
  node->f = f;
  node->c = c;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
inline void AddEdge(const int x, const int y, const int f, const int c)
{ add_edge(y, x, 0, -c, add_edge(x, y, f, c)); }/*}}}*/
struct AugRoad/*{{{*/
{
  int pre;
  Edge* e;
  void operator()(const int p, Edge* const x) { pre = p, e = x; }
} augroad[VERTEXS];
int S, T;
bool SPFA()
{
  static int dist[VERTEXS];
  static bool set[VERTEXS];
  static std::queue<int> Q;
  memset(dist, 0xC0, sizeof(dist));
  dist[S] = 0, set[S] = true;
  Q.push(S);
  for (int u; !Q.empty(); Q.pop(), set[u] = false)
  {
    u = Q.front();
    for (Edge *e = header[u]; e; e = e->next)
      if (e->f > 0 && dist[u] + e->c > dist[e->v])
      {
        dist[e->v] = dist[u] + e->c;
        augroad[e->v](u, e);
        if (!set[e->v])
        {
          set[e->v] = true;
          Q.push(e->v);
        }
      }
  }
  return dist[T] != static_cast<int>(0xC0C0C0C0);
}
int Costflow()
{
  int cost = 0;
  while (SPFA())
  {
    int minflow = INF;
    for (int u = T; u != S; u = augroad[u].pre)
      minflow = std::min(minflow, augroad[u].e->f);
    for (int u = T; u != S; u = augroad[u].pre)
    {
      cost += minflow * augroad[u].e->c;
      augroad[u].e->f -= minflow;
      augroad[u].e->op->f += minflow;
    }
  }
  return cost;
}/*}}}*/
void clear()/*{{{*/
{
  LinkSize = 0;
  memset(header, 0, sizeof(header));
}/*}}}*/
void solve1()/*{{{*/
{
  for (int i = 0; i < m; ++i)
    AddEdge(S, id[0][i], 1, 0);
  for (int i = 0; i < n; ++i)
    for (int j = 0; j < i+m; ++j)
    {
      AddEdge(id[i][j], id[i][j]+tot, 1, 0);
      if (i == n-1) continue;
      AddEdge(id[i][j]+tot, id[i+1][j], 1, mat[i][j]);
      AddEdge(id[i][j]+tot, id[i+1][j+1], 1, mat[i][j]);
    }
  for (int i = 0; i < n+m-1; ++i)
    AddEdge(id[n-1][i]+tot, T, INF, mat[n-1][i]);
  printf("%d\n", Costflow());
}/*}}}*/
void solve2()/*{{{*/
{
  for (int i = 0; i < m; ++i)
    AddEdge(S, id[0][i], 1, 0);
  for (int i = 0; i < n-1; ++i)
    for (int j = 0; j < i+m; ++j)
    {
      AddEdge(id[i][j], id[i+1][j], 1, mat[i][j]);
      AddEdge(id[i][j], id[i+1][j+1], 1, mat[i][j]);
    }
  for (int i = 0; i < n+m-1; ++i)
    AddEdge(id[n-1][i], T, INF, mat[n-1][i]);
  printf("%d\n", Costflow());
}/*}}}*/
void solve3()/*{{{*/
{
  for (int i = 0; i < m; ++i)
    AddEdge(S, id[0][i], 1, 0);
  for (int i = 0; i < n-1; ++i)
    for (int j = 0; j < i+m; ++j)
    {
      AddEdge(id[i][j], id[i+1][j], INF, mat[i][j]);
      AddEdge(id[i][j], id[i+1][j+1], INF, mat[i][j]);
    }
  for (int i = 0; i < n+m-1; ++i)
    AddEdge(id[n-1][i], T, INF, mat[n-1][i]);
  printf("%d\n", Costflow());
}/*}}}*/
int main()
{
  freopen("prog816.in", "r", stdin); 
  freopen("prog816.out", "w", stdout); 
  S = VERTEXS-2, T = VERTEXS-1;
  scanf("%d%d", &m, &n);
  for (int i = 0; i < n; ++i)
    for (int j = 0; j < m+i; ++j)
    {
      scanf("%d", &mat[i][j]);
      id[i][j] = tot++;
    }
  solve1();
  clear();
  solve2();
  clear();
  solve3();
  fclose(stdin);fclose(stdout); 
}
