#include <queue>
#include <cstdio>
#include <cstring>
#include <iostream>

const int INF = 0x3F3F3F3F;
const int MAXN = 100, MAXM = 100;
const int VERTEXS = MAXN+MAXM+2;
struct Edge/*{{{*/
{
  int v, f, c;
  Edge *next, *op;
} g[(MAXN+MAXM+MAXN*MAXM)*2], *header[VERTEXS];
int LinkSize = 0;
Edge* add_edge(const int x, const int y, const int f, const int c, Edge* const op = 0)
{
  Edge* node = g+(LinkSize++);
  node->v = y;
  node->f = f;
  node->c = c;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
inline void AddEdge(const int x, const int y, const int f, const int c)
{ add_edge(y, x, 0, -c, add_edge(x, y, f, c)); }/*}}}*/
struct AugRoad/*{{{*/
{
  int pre;
  Edge* e;
  void operator()(const int p, Edge* const x) { pre = p, e = x; }
} augroad[VERTEXS];
int S, T;
bool SPFA(const int reverse)
{
  static int dist[VERTEXS];
  static bool set[VERTEXS];
  static std::queue<int> Q;
  memset(dist, reverse == 1 ? 0x3F : 0xC0, sizeof(dist));
  dist[S] = 0, set[S] = true;
  Q.push(S);
  for (int u; !Q.empty(); Q.pop(), set[u] = false)
  {
    u = Q.front();
    for (Edge *e = header[u]; e; e = e->next)
      if (e->f > 0 && (dist[u] + e->c - dist[e->v])*reverse < 0)
      {
        dist[e->v] = dist[u] + e->c;
        augroad[e->v](u, e);
        if (!set[e->v])
        {
          set[e->v] = true;
          Q.push(e->v);
        }
      }
  }
  return dist[T] != (reverse == 1 ? INF : static_cast<int>(0xC0C0C0C0));
}
int Costflow(const int reverse)
{
  int cost = 0;
  while (SPFA(reverse))
  {
    int minflow = INF;
    for (int u = T; u != S; u = augroad[u].pre)
      minflow = std::min(minflow, augroad[u].e->f);
    for (int u = T; u != S; u = augroad[u].pre)
    {
      cost += minflow * augroad[u].e->c;
      augroad[u].e->f -= minflow;
      augroad[u].e->op->f += minflow;
    }
  }
  return cost;
}/*}}}*/
int n;
void solve(const int reverse)/*{{{*/
{
  LinkSize = 0;
  memset(header, 0, sizeof(header));
  freopen("prog818.in", "r", stdin); 
  scanf("%d", &n);
  S = n+n, T = S+1;
  for (int i = 0; i < n; ++i)
  {
    AddEdge(S, i, 1, 0);
    AddEdge(i+n, T, 1, 0);
    for (int j = 0, x; j < n; ++j)
    {
      scanf("%d", &x);
      AddEdge(i, j+n, 1, x);
    }
  }
  printf("%d\n", Costflow(reverse));
  fclose(stdin);
}/*}}}*/
int main()
{
  freopen("prog818.out", "w", stdout); 
  solve(1);
  solve(-1);
  fclose(stdout);
}
