#include <queue>
#include <cstdio>
#include <cstring>
#include <iostream>

const int INF = 0x3F3F3F3F;
const int MAXN = 101;
const int VERTEXS = MAXN*MAXN+2;
struct Edge/*{{{*/
{
  int v, f, c;
  Edge *next, *op;
} g[(MAXN*MAXN+MAXN+MAXN)*2], *header[VERTEXS];
int LinkSize = 0;
Edge* add_edge(const int x, const int y, const int f, const int c, Edge* const op = 0)
{
  Edge* node = g+(LinkSize++);
  node->v = y;
  node->f = f;
  node->c = c;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
inline void AddEdge(const int x, const int y, const int f, const int c)
{ add_edge(y, x, 0, -c, add_edge(x, y, f, c)); }/*}}}*/
struct AugRoad/*{{{*/
{
  int pre;
  Edge* e;
  void operator()(const int p, Edge* const x) { pre = p, e = x; }
} augroad[VERTEXS];
int S, T;
bool SPFA()
{
  static int dist[VERTEXS];
  static bool set[VERTEXS];
  static std::queue<int> Q;
  memset(dist, 0xC0, sizeof(dist));
  dist[S] = 0, set[S] = true;
  Q.push(S);
  for (int u; !Q.empty(); Q.pop(), set[u] = false)
  {
    u = Q.front();
    for (Edge *e = header[u]; e; e = e->next)
      if (e->f > 0 && dist[u] + e->c > dist[e->v])
      {
        dist[e->v] = dist[u] + e->c;
        augroad[e->v](u, e);
        if (!set[e->v])
        {
          set[e->v] = true;
          Q.push(e->v);
        }
      }
  }
  return dist[T] != static_cast<int>(0xC0C0C0C0);
}
int Costflow()
{
  int cost = 0;
  while (SPFA())
  {
    int minflow = INF;
    for (int u = T; u != S; u = augroad[u].pre)
      minflow = std::min(minflow, augroad[u].e->f);
    for (int u = T; u != S; u = augroad[u].pre)
    {
      cost += minflow * augroad[u].e->c;
      augroad[u].e->f -= minflow;
      augroad[u].e->op->f += minflow;
    }
  }
  return cost;
}/*}}}*/
int A, B, P, Q;
inline int Point(const int x, const int y) { return x*(Q+1)+y; }
int main()
{
  freopen("prog820.in", "r", stdin); 
  freopen("prog820.out", "w", stdout); 
  scanf("%d%d%d%d", &A, &B, &P, &Q);
  S = (P+1)*(Q+1), T = S+1;
  for (int i = 0; i <= P; ++i)
    for (int j = 0, x; j < Q; ++j)
    {
      scanf("%d", &x);
      AddEdge(Point(i, j), Point(i, j+1), 1, x);
      AddEdge(Point(i, j), Point(i, j+1), INF, 0);
    }
  for (int j = 0; j <= Q; ++j)
    for (int i = 0, x; i < P; ++i)
    {
      scanf("%d", &x);
      AddEdge(Point(i, j), Point(i+1, j), 1, x);
      AddEdge(Point(i, j), Point(i+1, j), INF, 0);
    }
  for (int i = 0, k, x, y; i < A; ++i)
  {
    scanf("%d%d%d", &k, &x, &y);
    AddEdge(S, Point(x, y), k, 0);
  }
  for (int i = 0, k, x, y; i < B; ++i)
  {
    scanf("%d%d%d", &k, &x, &y);
    AddEdge(Point(x, y), T, k, 0);
  }
  printf("%d", Costflow());
  fclose(stdin);fclose(stdout); 
}
