#include <queue>
#include <vector>
#include <cstdio>
#include <cstring>
#include <iostream>
#include <algorithm>

const int INF = 0x3F3F3F3F;
const int MAXN = 500;
const int VERTEXS = MAXN*2+2;
struct Edge/*{{{*/
{
  int v, f, c;
  Edge *next, *op;
} g[(VERTEXS+2+MAXN)*2], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int f, const int c, Edge* const op = 0)
{
  static int LinkSize = 0;
  Edge* node = g+(LinkSize++);
  node->v = y;
  node->f = f;
  node->c = c;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
inline void AddEdge(const int x, const int y, const int f, const int c)
{ add_edge(y, x, 0, -c, add_edge(x, y, f, c)); }/*}}}*/
struct AugRoad/*{{{*/
{
  int pre;
  Edge* e;
  void operator()(const int p, Edge* const x) { pre = p, e = x; }
} augroad[VERTEXS];
int S, T;
bool SPFA()
{
  static int dist[VERTEXS];
  static bool set[VERTEXS];
  static std::queue<int> Q;
  memset(dist, 0xC0, sizeof(dist));
  dist[S] = 0, set[S] = true;
  Q.push(S);
  for (int u; !Q.empty(); Q.pop(), set[u] = false)
  {
    u = Q.front();
    for (Edge *e = header[u]; e; e = e->next)
      if (e->f > 0 && dist[u] + e->c > dist[e->v])
      {
        dist[e->v] = dist[u] + e->c;
        augroad[e->v](u, e);
        if (!set[e->v])
        {
          set[e->v] = true;
          Q.push(e->v);
        }
      }
  }
  return dist[T] != static_cast<int>(0xC0C0C0C0);
}
int Costflow()
{
  int cost = 0;
  while (SPFA())
  {
    int minflow = INF;
    for (int u = T; u != S; u = augroad[u].pre)
      minflow = std::min(minflow, augroad[u].e->f);
    for (int u = T; u != S; u = augroad[u].pre)
    {
      cost += minflow * augroad[u].e->c;
      augroad[u].e->f -= minflow;
      augroad[u].e->op->f += minflow;
    }
  }
  return cost;
}/*}}}*/
int n, K;
std::vector<int> v;
std::vector< std::pair<int, int> > interval;
int main()
{
  freopen("prog821.in", "r", stdin); 
  freopen("prog821.out", "w", stdout); 
  scanf("%d%d", &n, &K);
  for (int i = 0, lef, rig; i < n; ++i)
  {
    scanf("%d%d", &lef, &rig);
    interval.push_back(std::make_pair(lef, rig));
    v.push_back(lef);
    v.push_back(rig);
  }
  std::sort(v.begin(), v.end());
  v.resize(std::unique(v.begin(), v.end()) - v.begin());

  S = v.size(), T = v.size()+1;
  for (std::vector<int>::size_type i = 1; i < v.size(); ++i)
    AddEdge(i-1, i, INF, 0);
  AddEdge(S, 0, K, 0);
  AddEdge(v.size()-1, T, K, 0);
  for (std::vector< std::pair<int, int> >::iterator iter = interval.begin(); iter != interval.end(); ++iter)
    AddEdge(
      std::lower_bound(v.begin(), v.end(), iter->first) - v.begin(),
      std::lower_bound(v.begin(), v.end(), iter->second) - v.begin(),
      1,
      iter->second - iter->first
    );
  printf("%d", Costflow());
  fclose(stdin);fclose(stdout); 
}
