#include <cstdio>
#include <algorithm>

const int MAXN = 1000, MAXM = 10000;
const int VERTEXS = MAXN*2+2;
const int INF = 0x3F3F3F3F;
struct Edge
{
  int v, f;
  Edge *op, *next;
} g[(MAXN*2+MAXM)*2], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int w, Edge* const op = 0)
{
  static int LinkSize;
  Edge *node = g+(LinkSize++);
  node->v = y;
  node->f = w;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
int n, m;
int nodes, S, T, dist[VERTEXS], dc[VERTEXS];
int SAP(const int u, const int delta)
{
  if (u == T)
    return delta;
  int sum = 0, mindist = nodes;
  for (Edge *e = header[u]; e; e = e->next)
  {
    if (dist[u]-1 == dist[e->v] && e->f > 0)
    {
      int d = SAP(e->v, std::min(delta-sum, e->f));
      e->f -= d;
      e->op->f += d;
      sum += d;
      if (dist[S] >= nodes || sum == delta)
        return sum;
    }
    if (e->f > 0)
      mindist = std::min(mindist, dist[e->v]);
  }
  if (sum == 0)
  {
    if (!--dc[dist[u]])
      dist[S] = nodes;
    else
      ++dc[dist[u] = mindist+1];
  }
  return sum;
}
bool vis[MAXN+1];
void print(int u)
{
  for (bool doing = true; doing; )
  {
    printf("%d ", u);
    vis[u] = true;
    doing = false;
    for (Edge *e = header[u]; e; e = e->next)
      if (e->f == 0 && e->v != S && !vis[e->v - n])
      {
        u = e->v - n;
        doing = true;
        break;
      }
  }
}
int main()
{
  freopen("prog83.in", "r", stdin); 
  freopen("prog83.out", "w", stdout); 
  scanf("%d%d", &n, &m);
  S = 0, T = 2*n+1;

  for (int i = 1; i <= n; ++i)
  {
    add_edge(i, S, 0, add_edge(S, i, 1));
    add_edge(T, n+i, 0, add_edge(n+i, T, 1));
  }
  for (int x, y; m--; )
  {
    scanf("%d%d", &x, &y);
    add_edge(y+n, x, 0, add_edge(x, y+n, 1));
  }

  int maxflow = 0;
  dc[0] = nodes = n*2+2;
  while (dist[S] < nodes)
    maxflow += SAP(S, INF);

  for (int i = 1; i <= n; ++i)
    if (!vis[i])
    {
      print(i);
      printf("\n");
    }
  printf("%d", n-maxflow);
  fclose(stdin);fclose(stdout); 
}
