#include <cstdio>
#include <cstring>
#include <algorithm>

const int MAXN = 5000, MAXM = MAXN*10, OFFSET = MAXN;
const int VERTEXS = MAXN*2+2;
const int INF = 0x3F3F3F3F;
struct Edge
{
  int v, f;
  Edge *op, *next;
} g[(MAXN*2+MAXM)*2], *header[VERTEXS];
int LinkSize;
Edge* add_edge(const int x, const int y, const int w, Edge* const op = 0)
{
  Edge *node = g+(LinkSize++);
  node->v = y;
  node->f = w;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
int n, K, maxflow;
bool sqr[60*60+1];
int nodes, S, T, dist[VERTEXS], dc[VERTEXS];/*{{{*/
int SAP(const int u, const int delta)
{
  if (u == T)
    return delta;
  int sum = 0, mindist = nodes;
  for (Edge *e = header[u]; e; e = e->next)
  {
    if (dist[u]-1 == dist[e->v] && e->f > 0)
    {
      int d = SAP(e->v, std::min(delta-sum, e->f));
      e->f -= d;
      e->op->f += d;
      sum += d;
      if (dist[S] >= nodes || sum == delta)
        return sum;
    }
    if (e->f > 0)
      mindist = std::min(mindist, dist[e->v]);
  }
  if (sum == 0)
  {
    if (!--dc[dist[u]])
      dist[S] = nodes;
    else
      ++dc[dist[u] = mindist+1];
  }
  return sum;
}
int Maxflow()
{
  int maxflow = 0;
  memset(dc, 0, sizeof(dc));
  memset(dist, 0, sizeof(dist));
  dc[0] = nodes = n*2+2;
  while (dist[S] < nodes)
    maxflow += SAP(S, INF);
  return maxflow;
}
bool vis[MAXN+1];
void print(int u)
{
  for (bool doing = true; doing; )
  {
    printf("%d ", u);
    vis[u] = true;
    doing = false;
    for (Edge *e = header[u]; e; e = e->next)
      if (e->f == 0 && e->v != S && !vis[e->v - OFFSET])
      {
        u = e->v - OFFSET;
        doing = true;
        break;
      }
  }
}/*}}}*/
int main()
{
  freopen("prog84.in", "r", stdin); 
  freopen("prog84.out", "w", stdout); 

  S = 0, T = VERTEXS-1;
  for (int i = 1; i <= 60; ++i) 
    sqr[i*i] = true;
  scanf("%d", &K);
  add_edge(1, S, 0, add_edge(S, 1, 1));
  add_edge(T, 1+OFFSET, 0, add_edge(1+OFFSET, T, 1));
  for (n = 1; n - (maxflow += Maxflow()) <= K; )
  {
    ++n;
    add_edge(n, S, 0, add_edge(S, n, 1));
    add_edge(T, n+OFFSET, 0, add_edge(n+OFFSET, T, 1));
    for (int i = 1; i < n; ++i)
      if (sqr[i+n])
        add_edge(n+OFFSET, i, 0, add_edge(i, n+OFFSET, 1));
  }
  --n;
  memset(header, 0, sizeof(header));
  LinkSize = 0;
  for (int j = 1; j <= n; ++j)
  {
    add_edge(j, S, 0, add_edge(S, j, 1));
    add_edge(T, j+OFFSET, 0, add_edge(j+OFFSET, T, 1));
    for (int i = 1; i < j; ++i)
      if (sqr[i+j])
        add_edge(j+OFFSET, i, 0, add_edge(i, j+OFFSET, 1));
  }
  maxflow = Maxflow();

  printf("%d\n", n);
  for (int i = 1; i <= n; ++i)
    if (!vis[i])
    {
      print(i);
      printf("\n");
    }

  fclose(stdin);fclose(stdout); 
}
