#include <cstdio>
#include <cstring>
#include <algorithm>

const int MAXN = 270, MAXM = 150;
const int VERTEXS = MAXN+MAXM+2;
const int INF = 0x3F3F3F3F;
struct Edge
{
  int v, f;
  Edge *op, *next;
} g[(MAXN+MAXM+MAXN*MAXM)*2], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int w, Edge* const op = 0)
{
  static int LinkSize;
  Edge *node = g+(LinkSize++);
  node->v = y;
  node->f = w;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
int n, m, maxflow, sum;
int nodes, S, T, dist[VERTEXS], dc[VERTEXS];/*{{{*/
int SAP(const int u, const int delta)
{
  if (u == T)
    return delta;
  int sum = 0, mindist = nodes;
  for (Edge *e = header[u]; e; e = e->next)
  {
    if (dist[u]-1 == dist[e->v] && e->f > 0)
    {
      int d = SAP(e->v, std::min(delta-sum, e->f));
      e->f -= d;
      e->op->f += d;
      sum += d;
      if (dist[S] >= nodes || sum == delta)
        return sum;
    }
    if (e->f > 0)
      mindist = std::min(mindist, dist[e->v]);
  }
  if (sum == 0)
  {
    if (!--dc[dist[u]])
      dist[S] = nodes;
    else
      ++dc[dist[u] = mindist+1];
  }
  return sum;
}
int Maxflow()
{
  int maxflow = 0;
  memset(dc, 0, sizeof(dc));
  memset(dist, 0, sizeof(dist));
  dc[0] = nodes = n+m+2;
  while (dist[S] < nodes)
    maxflow += SAP(S, INF);
  return maxflow;
}
bool vis[MAXN+1];
void print(const int u)
{
  for (Edge *e = header[u]; e; e = e->next)
    if (e->f == 0)
      printf("%d ", e->v - n);
  printf("\n");
}/*}}}*/
int main()
{
  freopen("prog85.in", "r", stdin); 
  freopen("prog85.out", "w", stdout); 

  scanf("%d%d", &n, &m);
  S = 0, T = n+m+1;
  for (int i = 1, x; i <= n; ++i)
  {
    scanf("%d", &x);
    add_edge(i, S, 0, add_edge(S, i, x));
    for (int j = m; j >= 1; --j)
      add_edge(j+n, i, 0, add_edge(i, j+n, 1));
    sum += x;
  }
  for (int i = 1, x; i <= m; ++i)
  {
    scanf("%d", &x);
    add_edge(T, n+i, 0, add_edge(n+i, T, x));
  }
  maxflow = Maxflow();

  if (maxflow == sum)
  {
    printf("1\n");
    for (int i = 1; i <= n; ++i)
      print(i);
  }
  else
    printf("0");

  fclose(stdin);fclose(stdout); 
}
