#include <cstdio>
#include <cstring>
#include <algorithm>

const int MAXN = 500, MAXM = 500*500/2;
const int VERTEXS = MAXN*2+2;
const int INF = 0x3F3F3F3F;
struct Edge
{
  int v, f;
  Edge *op, *next;
} g[(MAXN*2+MAXM+2)*2], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int w, Edge* const op = 0)
{
  static int LinkSize;
  Edge *node = g+(LinkSize++);
  node->v = y;
  node->f = w;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
int n, m, maxflow, sum, LIS, ans, a[MAXN+1], f[MAXN+1];
int nodes, S, T, dist[VERTEXS], dc[VERTEXS];/*{{{*/
int SAP(const int u, const int delta)
{
  if (u == T)
    return delta;
  int sum = 0, mindist = nodes;
  for (Edge *e = header[u]; e; e = e->next)
  {
    if (dist[u]-1 == dist[e->v] && e->f > 0)
    {
      int d = SAP(e->v, std::min(delta-sum, e->f));
      e->f -= d;
      e->op->f += d;
      sum += d;
      if (dist[S] >= nodes || sum == delta)
        return sum;
    }
    if (e->f > 0)
      mindist = std::min(mindist, dist[e->v]);
  }
  if (sum == 0)
  {
    if (!--dc[dist[u]])
      dist[S] = nodes;
    else
      ++dc[dist[u] = mindist+1];
  }
  return sum;
}
int Maxflow()
{
  int maxflow = 0;
  memset(dc, 0, sizeof(dc));
  memset(dist, 0, sizeof(dist));
  dc[0] = nodes = n*2+2;
  while (dist[S] < nodes)
    maxflow += SAP(S, INF);
  return maxflow;
}
/*}}}*/
int main()
{
  freopen("prog86.in", "r", stdin); 
  freopen("prog86.out", "w", stdout); 

  scanf("%d", &n);
  S = 0, T = n*2+1;
  for (int i = 1; i <= n; ++i)
    scanf("%d", a+i);
  for (int i = n; i >= 1; --i)
  {
    f[i] = 1;
    for (int j = i+1; j <= n; ++j)
      if (a[i] < a[j] && f[j]+1 > f[i])
        f[i] = f[j]+1;
    LIS = std::max(LIS, f[i]);
  }
  printf("%d\n", LIS);

  for (int i = 1; i <= n; ++i)
  {
    add_edge(i+n, i, 0, add_edge(i, i+n, i == 1 || i == n ? INF : 1));
    if (f[i] == 1)
      add_edge(T, i+n, 0, add_edge(i+n, T, 1));
    if (f[i] == LIS)
      add_edge(i, S, 0, add_edge(S, i, 1));
    for (int j = i+1; j <= n; ++j)
      if (a[i] < a[j] && f[j]+1 == f[i])
        add_edge(j, i+n, 0, add_edge(i+n, j, 1));
  }
  printf("%d\n", ans = Maxflow());

  for (Edge *e = header[S]; e; e = e->next)
    if (e->v == 1)
    {
      e->f = INF;
      break;
    }
  for (Edge *e = header[n+n]; e; e = e->next)
    if (e->v == T)
    {
      e->f = INF;
      break;
    }
  printf("%d", ans+Maxflow());

  fclose(stdin);fclose(stdout); 
}
