#include <cstdio>
#include <cstring>
#include <algorithm>

const int MAXM = 1000, MAXN = 20;
const int VERTEXS = MAXN+MAXM+2;
const int INF = 0x3F3F3F3F;
struct Edge
{
  int v, f;
  Edge *op, *next;
} g[(MAXN+MAXM+MAXN*MAXM)*2], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int w, Edge* const op = 0)
{
  static int LinkSize;
  Edge *node = g+(LinkSize++);
  node->v = y;
  node->f = w;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}
int n, m, maxflow, sum, num[MAXN];
int nodes, S, T, dist[VERTEXS], dc[VERTEXS];/*{{{*/
int SAP(const int u, const int delta)
{
  if (u == T)
    return delta;
  int sum = 0, mindist = nodes;
  for (Edge *e = header[u]; e; e = e->next)
  {
    if (dist[u]-1 == dist[e->v] && e->f > 0)
    {
      int d = SAP(e->v, std::min(delta-sum, e->f));
      e->f -= d;
      e->op->f += d;
      sum += d;
      if (dist[S] >= nodes || sum == delta)
        return sum;
    }
    if (e->f > 0)
      mindist = std::min(mindist, dist[e->v]);
  }
  if (sum == 0)
  {
    if (!--dc[dist[u]])
      dist[S] = nodes;
    else
      ++dc[dist[u] = mindist+1];
  }
  return sum;
}
int Maxflow()
{
  int maxflow = 0;
  memset(dc, 0, sizeof(dc));
  memset(dist, 0, sizeof(dist));
  dc[0] = nodes = n+m+2;
  while (dist[S] < nodes)
    maxflow += SAP(S, INF);
  return maxflow;
}
void print(const int u)
{
  for (Edge *e = header[u]; e; e = e->next)
    if (e->f == 0)
      printf("%d ", e->v - n);
}/*}}}*/
int main()
{
  freopen("prog87.in", "r", stdin); 
  freopen("prog87.out", "w", stdout); 

  scanf("%d%d", &n, &m);
  S = 0, T = n+m+1;
  for (int i = 1; i <= n; ++i)
  {
    scanf("%d", num+i-1);
    sum += num[i-1];
    add_edge(i, S, 0, add_edge(S, i, num[i-1]));
  }
  for (int i = 1, num; i <= m; ++i)
  {
    scanf("%d", &num);
    add_edge(T, n+i, 0, add_edge(n+i, T, 1));
    for (int x; num--; )
    {
      scanf("%d", &x);
      add_edge(n+i, x, 0, add_edge(x, n+i, 1));
    }
  }
  if (Maxflow() != sum)
    printf("No Solution!");
  else
  {
    for (int i = 1; i <= n; ++i)
    {
      printf("%d: ", i);
      if (num[i-1] != 0)
        print(i);
      printf("\n");
    }
  }

  fclose(stdin);fclose(stdout); 
}
