#include <cstdio>
#include <cstring>
#include <algorithm>

const int MAXN = 50*50, MAXM = MAXN*2;
const int VERTEXS = MAXN+2;
const int INF = 0x3F3F3F3F;
struct Edge
{
  int v, f;
  Edge *op, *next;
} g[(MAXN+MAXM)*2], *header[VERTEXS];
Edge* add_edge(const int x, const int y, const int w, Edge* const op = 0)/*{{{*/
{
  static int LinkSize;
  Edge *node = g+(LinkSize++);
  node->v = y;
  node->f = w;
  node->op = op;
  node->next = header[x];
  if (op)
    op->op = node;
  return header[x] = node;
}/*}}}*/
int n, m, sum;
int nodes, S, T, dist[VERTEXS], dc[VERTEXS];/*{{{*/
int SAP(const int u, const int delta)
{
  if (u == T)
    return delta;
  int sum = 0, mindist = nodes;
  for (Edge *e = header[u]; e; e = e->next)
  {
    if (dist[u]-1 == dist[e->v] && e->f > 0)
    {
      int d = SAP(e->v, std::min(delta-sum, e->f));
      e->f -= d;
      e->op->f += d;
      sum += d;
      if (dist[S] >= nodes || sum == delta)
        return sum;
    }
    if (e->f > 0)
      mindist = std::min(mindist, dist[e->v]);
  }
  if (sum == 0)
  {
    if (!--dc[dist[u]])
      dist[S] = nodes;
    else
      ++dc[dist[u] = mindist+1];
  }
  return sum;
}
int Maxflow()
{
  int maxflow = 0;
  memset(dc, 0, sizeof(dc));
  memset(dist, 0, sizeof(dist));
  dc[0] = nodes = n*m+2;
  while (dist[S] < nodes)
    maxflow += SAP(S, INF);
  return maxflow;
} /*}}}*/
inline int pos(const int x, const int y) { return x*m+y+1; }
inline void insert(const int p, const int x, const int y)
{
  if (x < 0 || x >= n || y < 0 || y >= m) return;
  const int p2 = pos(x, y);
  add_edge(p2, p, 0, add_edge(p, p2, INF));
}
int main()
{
  freopen("prog89.in", "r", stdin); 
  freopen("prog89.out", "w", stdout); 

  scanf("%d%d", &n, &m);
  S = 0, T = n*m+1;
  for (int i = 0; i < n; ++i)
    for (int j = 0, x; j < m; ++j)
    {
      scanf("%d", &x);
      sum += x;
      const int p = pos(i, j);
      if ((i+j)&1)
      {
        add_edge(p, S, 0, add_edge(S, p, x));
        insert(p, i-1, j);
        insert(p, i+1, j);
        insert(p, i, j-1);
        insert(p, i, j+1);
      }
      else
        add_edge(T, p, 0, add_edge(p, T, x));
    }
  printf("%d\n", sum - Maxflow());

  fclose(stdin);fclose(stdout); 
}
